@@ -51,7 +51,7 @@ class MultipleInstances(Exception):
     pass
 
 
-def raiser(e: Exception) -> Callable[[], None]:
+def raiser(e: Exception) -> Callable:
     def inner(*_):
         raise e
 
@@ -181,11 +181,9 @@ def config_list(db: FADatabase, *_rest):
         Prints a list of stored settings.
     """
 
-    cookie_a, cookie_b = read_cookies(db)
-    folder: str = db.settings["FILESFOLDER"]
-    print("cookie a:", cookie_a)
-    print("cookie b:", cookie_b)
-    print("folder  :", folder)
+    for c in read_cookies(db):
+        print(f"cookie {c['name']}:", c['value'])
+    print("files folder:", db.settings["FILESFOLDER"])
 
 
 def config_cookies(db: FADatabase, *args: str):
@@ -404,7 +402,8 @@ def download(db: FADatabase, comm: str = "", *args: str):
 
     DESCRIPTION
         The download command performs all download operations get and update users,
-        submissions, and journals.
+        submissions, and journals. Submissions are downloaded together with their
+        thumbnails, if there are any.
     """
 
     if not comm:
@@ -490,9 +489,9 @@ def database_search_submissions(db: FADatabase, *args: str):
         supplied, a list of all submissions will be returned instead.
 
     EXAMPLES
-        falocalrepo database search-submissions tags=%cat,%mouse% date=2020-% \\
+        falocalrepo database search-submissions tags=%|cat|%|mouse|% date=2020-% \\
             category=%artwork% order="AUTHOR" order="ID"
-        falocalrepo database search-submissions tags=%cat% tags=%mouse% \\
+        falocalrepo database search-submissions tags=%|cat|% tags=%|mouse|% \\
             date=2020-% category=%artwork%
     """
 
@@ -584,6 +583,7 @@ def database_add_submission(db: FADatabase, *args: str):
             * 'species'
             * 'gender'
             * 'rating'
+            * 'type' image, text, music, or flash
             * 'folder' gallery or scraps
         The following parameters are optional:
             * 'tags' comma-separated tags
@@ -595,7 +595,7 @@ def database_add_submission(db: FADatabase, *args: str):
     EXAMPLES
         falocalrepo database add-submission id=12345678 title='cat & mouse' \\
             author=CartoonArtist date=2020-08-09 category=Artwork \\
-            species='Unspecified / Any' gender=Any rating=General \\
+            species='Unspecified / Any' gender=Any rating=General type=image \\
             tags=cat,mouse,cartoon description="$(cat description.html)" \\
             file_url='http://remote.url/to/submission.file' \\
             file_local_url='path/to/submission.file' folder=gallery
@@ -603,8 +603,11 @@ def database_add_submission(db: FADatabase, *args: str):
 
     make_params = parameters(args)
     make_params["id_"] = make_params.get("id", "")
+    make_params["type_"] = make_params.get("type", "")
     if "id" in make_params:
         del make_params["id"]
+    if "type" in make_params:
+        del make_params["type_"]
     save_submission(db, *make_submission(**make_params), user_update=False)
 
 
@@ -794,7 +797,8 @@ def database(db: FADatabase, comm: str = "", *args: str):
         expression can be used to search two words together separated by an unknown
         amount of characters '%cat%mouse%'. Fields missing wildcards will only match
         an exact result, i.e. 'cat' will only match a field equal to 'cat' tag
-        whereas '%cat%' wil match a field that has contains 'cat'.
+        whereas '%cat%' wil match a field that has contains 'cat'. Bars ('|') can be
+        used to isolate individual items in list fields.
 
         All search operations support the extra 'order', 'limit', and 'offset'
         parameters with values in SQLite 'ORDER BY' clause, 'LIMIT' clause format,
